@@ -1,5 +1,8 @@
 # coding=utf-8
 """
+hangman.__main__
+~~~~~~~~~~~~~~~~
+
 Entry point for ``hangman`` command.
 """
 from __future__ import absolute_import
